==> owncloud-10.2.0.zip: owncloud/settings/l10n/vi.js <==
OC.L10N.register(
    "settings",
    {
    "Authentication error" : "Lỗi xác thực",
    "Saved" : "Đã lưu",
    "Email sent" : "Email đã được gửi",
    "Your full name has been changed." : "Họ và tên đã được thay đổi.",
    "Unable to change full name" : "Họ và tên không thể đổi ",
    "__language_name__" : "__Ngôn ngữ___",
    "Language changed" : "Ngôn ngữ đã được thay đổi",
    "Invalid request" : "Yêu cầu không hợp lệ",
    "Admins can't remove themself from the admin group" : "Quản trị viên không thể loại bỏ chính họ khỏi nhóm quản lý",
    "All" : "Tất cả",
    "Enabled" : "Bật",
    "Please wait...." : "Xin hãy đợi...",
    "Disable" : "Tắt",
    "Enable" : "Bật",
    "Updating...." : "Đang cập nhật...",
    "Error while updating app" : "Lỗi khi cập nhật ứng dụng",
    "Updated" : "Đã cập nhật",
    "Delete" : "Xóa",
    "Select a profile picture" : "Chọn một ảnh hồ sơ",
    "Groups" : "Nhóm",
    "undo" : "lùi lại",
    "never" : "không thay đổi",
    "Cheers!" : "Chúc mừng!",
    "Forum" : "Diễn đàn",
    "Cron" : "Cron",
    "Open documentation" : "Mở tài liệu",
    "Execute one task with each page loaded" : "Thực thi tác vụ mỗi khi trang được tải",
    "Sharing" : "Chia sẻ",
    "Allow apps to use the Share API" : "Cho phép các ứng dụng sử dụng chia sẻ API",
    "Allow resharing" : "Cho phép chia sẻ lại",
    "Log" : "Log",
    "None" : "Không gì cả",
    "Login" : "Đăng nhập",
    "Encryption" : "Mã hóa",
    "Server address" : "Địa chỉ máy chủ",
    "Port" : "Cổng",
    "Credentials" : "Giấy chứng nhận",
    "Security & setup warnings" : "Bảo mật và thiết lập cảnh báo",
    "Get the apps to sync your files" : "Nhận ứng dụng để đồng bộ file của bạn",
    "Show First Run Wizard again" : "Hiện lại việc chạy đồ thuật khởi đầu",
    "Profile picture" : "Ảnh hồ sơ",
    "Upload new" : "Tải lên",
    "Remove image" : "Xóa ",
    "Cancel" : "Hủy",
    "Choose as profile picture" : "Chọn hình ảnh làm ảnh hồ sơ",
    "Full name" : "Họ và tên",
    "Email" : "Email",
    "Your email address" : "Email của bạn",
    "Password" : "Mật khẩu",
    "Unable to change your password" : "Không thể đổi mật khẩu",
    "Current password" : "Mật khẩu cũ",
    "New password" : "Mật khẩu mới",
    "Change password" : "Đổi mật khẩu",
    "Language" : "Ngôn ngữ",
    "Help translate" : "Hỗ trợ dịch thuật",
    "Unlimited" : "Không giới hạn",
    "Sessions" : "Phiên làm việc",
    "These are the web, desktop and mobile clients currently logged in to your ownCloud." : "Danh sách các thiết bị điện thoại, web và máy tính hiện tại đã đăng nhập vào ownCould của bạn.",
    "Browser" : "Trình duyệt",
    "Most recent activity" : "Hoạt động gần đây nhất",
    "Name" : "Tên",
    "Username" : "Tên đăng nhập",
    "Version" : "Phiên bản",
    "Personal" : "Cá nhân",
    "Admin" : "Quản trị",
    "Error" : "Lỗi",
    "Create" : "Tạo",
    "Group" : "N",
    "Default Quota" : "Hạn ngạch mặt định",
    "Other" : "Khác",
    "Full Name" : "Họ và tên",
    "Quota" : "Hạn ngạch",
    "change full name" : "Đổi họ và t",
    "set new password" : "đặt mật khẩu mới",
    "Default" : "Mặc định",
    "Share" : "Chia sẻ",
    "Add" : "Thêm",
    "Add Domain" : "Thêm tên miền",
    "Common Name" : "Tên gọi chung",
    "Admin documentation" : "Tài liệu quản trị",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Đã xảy ra sự cố khi gửi email. Hãy sửa lại cài đặt của bạn.(Lỗi: %s)",
    "Domain" : "Tên miền",
    "The new password can not be the same as the previous one" : "Mật khẩu mới không được giống với mật khẩu trước đó",
    "Change" : "Thay đổi",
    "APCu" : "APCu",
    "Official" : "Official",
    "Approved" : "Approved",
    "Disconnect" : "Ngắt kết nối",
    "User documentation" : "Tài liệu người dùng",
    "Administrator documentation" : "Tài liệu của quản trị viên",
    "Online documentation" : "Tài liệu trực tuyến",
    "Commercial support" : "Hỗ trợ thương mại",
    "Apps Management" : "Quản lý ứng dụng",
    "by %s" : "bởi %s",
    "Visit website" : "Truy cập trang web",
    "Show enabled apps" : "Hiện ứng dụng đã bật",
    "Show disabled apps" : "Hiện ứng dụng đã tắt",
    "System Status" : "Trạng thái hệ thống",
    "Select from Files" : "Chọn từ tập tin",
    "png or jpg, max. 20 MB" : "png or jpg, tối đa. 20 MB",
    "Picture provided by original account" : "Hình ảnh được cung cấp bởi tài khoản gốc",
    "Change email" : "Thay đổi email",
    "Set email" : "Thiết lập email",
    "For password recovery and notifications" : "Để khôi phục mật khẩu và thông báo",
    "App passwords" : "Mật khẩu ứng dụng",
    "App name" : "Tên ứng dụng",
    "Create new app password" : "Tạo mật khẩu ứng dụng mới",
    "Invalid email address" : "Địa chỉ email không hợp lệ",
    "White-listed Domains" : "Danh sách tên miền cho phép",
    "installing and updating apps via the market or Federated Cloud Sharing" : "cài đặt và cập nhật ứng dụng thông qua market hoặc Federated Cloud Sharing",
    "You are using %s of %s (%s %%)" : "Bạn đang sử dụng %s of %s (%s %%)",
    "Uninstall App" : "Gỡ ứng dụng",
    "Done" : "Xong",
    "Uninstall" : "Gỡ cài đặt",
    "test email settings" : "Kiểm tra cài đặt email",
    "Wrong password" : "Sai mật khẩu",
    "Redis" : "Redis",
    "Not enabled" : "Chưa bật",
    "No apps found for your version" : "Không tìm thấy phiên bản của ứng dụng",
    "Developer documentation" : "Tài liệu của nhà phát triển",
    "Report a bug" : "Báo cáo lỗi",
    "Android app" : "Ứng dụng Android",
    "iOS app" : "Ứng dụng iOS",
    "No display name set" : "Chưa đặt tên hiển thị",
    "No email address set" : "Chưa đặt địa chỉ email",
    "%s password changed successfully" : "%smật khẩu đã được thay đổi thành công",
    "Couldn't send reset email. Please contact your administrator." : "Không thể gửi email đặt lại. Vui lòng liên hệ với quản trị viên của bạn.",
    "Couldn't remove app." : "Không thể xóa ứng dụng.",
    "Uninstalling ...." : "Đang gở bỏ....",
    "Sending..." : "Đang gửi...",
    "Documentation:" : "Tài liệu:",
    "Show description …" : "Hiển thị mô tả ...",
    "Hide description …" : "Ẩn mô tả ...",
    "No Domains." : "Không có tên miền.",
    "Are you sure you want to remove this domain?" : "Bạn có chắc chắn muốn xóa miền này?",
    "You are member of the following groups:" : "Bạn là thành viên của các nhóm sau:",
    "You've linked these apps." : "Bạn đã liên kết các ứng dụng này.",
    "An app password is a passcode that gives an app or device permissions to access your %s account." : "Mật khẩu ứng dụng là mật mã cho phép ứng dụng hoặc thiết bị truy cập vào tài khoản %s của bạn.",
    "No panels for this section." : "Không có điều khiển cho phần này.",
    "cURL is using an outdated %s version (%s). Please update your operating system or features such as %s will not work reliably." : "cURL đang sử dụng một phiên bản %s đã lỗi thời (%s). Vui lòng cập nhật hệ thống hoặc các tính năng của bạn chẳng hạn như %s sẽ không hoạt động nhưu mong đợi.",
    "All checks passed." : "Tất cả kiểm tra đều thông qua.",
    "Use the credentials below to configure your app or device." : "Sử dụng các thông tin dưới đây để cấu hình ứng dụng hoặc thiết bị của bạn.",
    "You are not a member of any groups." : "Bạn không phải là thành viên của bất kỳ nhóm nào.",
    "You need to set your user email before being able to send test emails." : "Bạn cần đặt email người dùng của mình trước khi có gửi email thử nghiệm."
},
"nplurals=1; plural=0;");

==> owncloud-10.4.0.zip: owncloud/settings/l10n/vi.js <==
OC.L10N.register(
    "settings",
    {
    "Authentication error" : "Lỗi xác thực",
    "%s password changed successfully" : "%smật khẩu đã được thay đổi thành công",
    "Couldn't send reset email. Please contact your administrator." : "Không thể gửi email đặt lại. Vui lòng liên hệ với quản trị viên của bạn.",
    "installing and updating apps via the market or Federated Cloud Sharing" : "cài đặt và cập nhật ứng dụng thông qua market hoặc Federated Cloud Sharing",
    "cURL is using an outdated %s version (%s). Please update your operating system or features such as %s will not work reliably." : "cURL đang sử dụng một phiên bản %s đã lỗi thời (%s). Vui lòng cập nhật hệ thống hoặc các tính năng của bạn chẳng hạn như %s sẽ không hoạt động nhưu mong đợi.",
    "Saved" : "Đã lưu",
    "Invalid email address" : "Địa chỉ email không hợp lệ",
    "test email settings" : "Kiểm tra cài đặt email",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Đã xảy ra sự cố khi gửi email. Hãy sửa lại cài đặt của bạn.(Lỗi: %s)",
    "Email sent" : "Email đã được gửi",
    "You need to set your user email before being able to send test emails." : "Bạn cần đặt email người dùng của mình trước khi có gửi email thử nghiệm.",
    "Your full name has been changed." : "Họ và tên đã được thay đổi.",
    "Unable to change full name" : "Họ và tên không thể đổi ",
    "Create" : "Tạo",
    "Change" : "Thay đổi",
    "Delete" : "Xóa",
    "Share" : "Chia sẻ",
    "APCu" : "APCu",
    "Redis" : "Redis",
    "Language changed" : "Ngôn ngữ đã được thay đổi",
    "Invalid request" : "Yêu cầu không hợp lệ",
    "Admins can't remove themself from the admin group" : "Quản trị viên không thể loại bỏ chính họ khỏi nhóm quản lý",
    "Couldn't remove app." : "Không thể xóa ứng dụng.",
    "Official" : "Official",
    "Approved" : "Approved",
    "All" : "Tất cả",
    "Enabled" : "Bật",
    "Not enabled" : "Chưa bật",
    "No apps found for your version" : "Không tìm thấy phiên bản của ứng dụng",
    "Please wait...." : "Xin hãy đợi...",
    "Disable" : "Tắt",
    "Enable" : "Bật",
    "Updating...." : "Đang cập nhật...",
    "Error while updating app" : "Lỗi khi cập nhật ứng dụng",
    "Updated" : "Đã cập nhật",
    "Uninstalling ...." : "Đang gở bỏ....",
    "Uninstall" : "Gỡ cài đặt",
    "Disconnect" : "Ngắt kết nối",
    "Sending..." : "Đang gửi...",
    "Select a profile picture" : "Chọn một ảnh hồ sơ",
    "Groups" : "Nhóm",
    "undo" : "lùi lại",
    "Delete group" : "Xóa nhóm",
    "never" : "không bao gi",
    "Cheers!" : "Chúc mừng!",
    "User documentation" : "Tài liệu người dùng",
    "Administrator documentation" : "Tài liệu của quản trị viên",
    "Developer documentation" : "Tài liệu của nhà phát triển",
    "Online documentation" : "Tài liệu trực tuyến",
    "Forum" : "Diễn đàn",
    "Commercial support" : "Hỗ trợ thương mại",
    "Language" : "Ngôn ngữ",
    "Apps Management" : "Quản lý ứng dụng",
    "by %s" : "bởi %s",
    "Documentation:" : "Tài liệu:",
    "Admin documentation" : "Tài liệu quản trị",
    "Visit website" : "Truy cập trang web",
    "Report a bug" : "Báo cáo lỗi",
    "Show description …" : "Hiển thị mô tả ...",
    "Hide description …" : "Ẩn mô tả ...",
    "Uninstall App" : "Gỡ ứng dụng",
    "Show enabled apps" : "Hiện ứng dụng đã bật",
    "Show disabled apps" : "Hiện ứng dụng đã tắt",
    "Cron" : "Cron",
    "Open documentation" : "Mở tài liệu",
    "Execute one task with each page loaded" : "Thực thi tác vụ mỗi khi trang được tải",
    "Common Name" : "Tên gọi chung",
    "Sharing" : "Chia sẻ",
    "Allow apps to use the Share API" : "Cho phép các ứng dụng sử dụng chia sẻ API",
    "Allow resharing" : "Cho phép chia sẻ lại",
    "None" : "Không gì cả",
    "Log" : "Log",
    "Login" : "Đăng nhập",
    "Encryption" : "Mã hóa",
    "Server address" : "Địa chỉ máy chủ",
    "Port" : "Cổng",
    "Credentials" : "Giấy chứng nhận",
    "Security & setup warnings" : "Bảo mật và thiết lập cảnh báo",
    "All checks passed." : "Tất cả kiểm tra đều thông qua.",
    "System Status" : "Trạng thái hệ thống",
    "Get the apps to sync your files" : "Nhận ứng dụng để đồng bộ file của bạn",
    "Android app" : "Ứng dụng Android",
    "iOS app" : "Ứng dụng iOS",
    "Show First Run Wizard again" : "Hiện lại việc chạy đồ thuật khởi đầu",
    "White-listed Domains" : "Danh sách tên miền cho phép",
    "No Domains." : "Không có tên miền.",
    "Domain" : "Tên miền",
    "Are you sure you want to remove this domain?" : "Bạn có chắc chắn muốn xóa miền này?",
    "Add Domain" : "Thêm tên miền",
    "Add" : "Thêm",
    "Profile picture" : "Ảnh hồ sơ",
    "Upload new" : "Tải lên",
    "Select from Files" : "Chọn từ tập tin",
    "Remove image" : "Xóa ",
    "png or jpg, max. 20 MB" : "png or jpg, tối đa. 20 MB",
    "Picture provided by original account" : "Hình ảnh được cung cấp bởi tài khoản gốc",
    "Cancel" : "Hủy",
    "Choose as profile picture" : "Chọn hình ảnh làm ảnh hồ sơ",
    "Full name" : "Họ và tên",
    "No display name set" : "Chưa đặt tên hiển thị",
    "Email" : "Email",
    "Your email address" : "Email của bạn",
    "Change email" : "Thay đổi email",
    "Set email" : "Thiết lập email",
    "For password recovery and notifications" : "Để khôi phục mật khẩu và thông báo",
    "No email address set" : "Chưa đặt địa chỉ email",
    "You are member of the following groups:" : "Bạn là thành viên của các nhóm sau:",
    "You are not a member of any groups." : "Bạn không phải là thành viên của bất kỳ nhóm nào.",
    "Password" : "Mật khẩu",
    "Unable to change your password" : "Không thể đổi mật khẩu",
    "Current password" : "Mật khẩu cũ",
    "New password" : "Mật khẩu mới",
    "Change password" : "Đổi mật khẩu",
    "Help translate" : "Hỗ trợ dịch thuật",
    "You are using %s of %s (%s %%)" : "Bạn đang sử dụng %s of %s (%s %%)",
    "Sessions" : "Phiên làm việc",
    "Browser" : "Trình duyệt",
    "Most recent activity" : "Hoạt động gần đây nhất",
    "You've linked these apps." : "Bạn đã liên kết các ứng dụng này.",
    "Name" : "Tên",
    "App name" : "Tên ứng dụng",
    "Use the credentials below to configure your app or device." : "Sử dụng các thông tin dưới đây để cấu hình ứng dụng hoặc thiết bị của bạn.",
    "Username" : "Tên đăng nhập",
    "Done" : "Xong",
    "Version" : "Phiên bản",
    "Personal" : "Cá nhân",
    "Admin" : "Quản trị",
    "Other" : "Khác",
    "No panels for this section." : "Không có điều khiển cho phần này.",
    "Settings" : "Thiết lập",
    "Group" : "N",
    "Default Quota" : "Hạn ngạch mặt định",
    "Unlimited" : "Không giới hạn",
    "Full Name" : "Họ và tên",
    "Quota" : "Hạn ngạch",
    "change full name" : "Đổi họ và t",
    "set new password" : "đặt mật khẩu mới",
    "Default" : "Mặc định"
},
"nplurals=1; plural=0;");
